==> box2d-0.1.5.tar.gz: example/benchmarks/benchmark_runner.dart <==
// Copyright 2012 Google Inc. All Rights Reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
//     http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

library BenchmarkRunner;

import 'dart:io';
import 'dart:math';
import 'package:args/args.dart';
import 'package:box2d/box2d.dart';

part 'benchmark.dart';
part 'ball_cage_bench.dart';
part 'ball_drop_bench.dart';
part 'circle_stress_bench.dart';
part 'domino_platform_bench.dart';
part 'domino_tower_bench.dart';

/** Runs the Dart Box2D benchmarks. Outputs results to console. */
class BenchmarkRunner {
  // TODO(dominich): Add timeout for benchmarks.
  /**
   * The different values for position/velocity solve iterations that one wishes
   * to benchmark. These are the arguments provided to the world's step
   * function and determine how many times to solve for velocity and position on
   * each step.
   */
  List<int> _solveLoops;

  /** The different values for number of steps that one wishes to benchmark. */
  List<int> _steps;

  /** The benchmarks to be run. Initialized in [setupBenchmarks]. */
  List<Benchmark> _benchmarks;

  /** Buffer results here before dumping out on the page. */
  StringBuffer _resultsWriter;

  BenchmarkRunner()
      : _resultsWriter = new StringBuffer(),
        _benchmarks = new List<Benchmark>(),
        _solveLoops = const [10, 30],
        _steps = const [10, 100, 500, 2000];

  /**
   * Adds the specified benchmarks to the benchmark suite. Modify this method
   * directly to determine which benchmarks are included and the order in which
   * they are run.
   */
  void setupBenchmarks(String filter) {
    final benchmarks = [
      new BallDropBench(_solveLoops, _steps),
      new BallCageBench(_solveLoops, _steps),
      new CircleStressBench(_solveLoops, _steps),
      new DominoPlatformBench(_solveLoops, _steps),
      new DominoTowerBench(_solveLoops, _steps),
    ];

    if (filter == null || filter.isEmpty) {
      benchmarks.map(_addBenchmark);
    } else {
      List<String> filterList = filter.split(",").map((e) => e.trim());
      benchmarks.where((e) => filterList.indexOf(e.name) != -1).map(_addBenchmark);
    }
  }

  /**
   * Runs and records the results of each benchmark included in [setupBenchmarks].
   */
  void runBenchmarks() {
    for (Benchmark benchmark in _benchmarks) {
      print('Running ${benchmark.name}');
      _resultsWriter.clear();
      benchmark.runBenchmark(_resultsWriter);
      print("$_resultsWriter------------------------------------------------");
    }
  }

  /**
   * Initializes the given benchmark and adds to the end of the queue of
   * benchmarks to run.
   */
  void _addBenchmark(Benchmark benchmark) => _benchmarks.add(benchmark);
}

void main() {
  // TODO(dominich): Options for step sizes.
  final runner = new BenchmarkRunner();

  var parser = new ArgParser();
  parser.addOption('filter', abbr: 'f');
  var results = parser.Parse(new Options().arguments);
  runner.setupBenchmarks(results['filter']);
  runner.runBenchmarks();
}

==> box2d-0.1.7.tar.gz: example/benchmarks/benchmark_runner.dart <==
// Copyright 2012 Google Inc. All Rights Reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
//     http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

library BenchmarkRunner;

import 'dart:io';
import 'dart:math';
import 'package:args/args.dart';
import 'package:box2d/box2d.dart';

part 'benchmark.dart';
part 'ball_cage_bench.dart';
part 'ball_drop_bench.dart';
part 'circle_stress_bench.dart';
part 'domino_platform_bench.dart';
part 'domino_tower_bench.dart';

/** Runs the Dart Box2D benchmarks. Outputs results to console. */
class BenchmarkRunner {
  // TODO(dominich): Add timeout for benchmarks.
  /**
   * The different values for position/velocity solve iterations that one wishes
   * to benchmark. These are the arguments provided to the world's step
   * function and determine how many times to solve for velocity and position on
   * each step.
   */
  List<int> _solveLoops;

  /** The different values for number of steps that one wishes to benchmark. */
  List<int> _steps;

  /** The benchmarks to be run. Initialized in [setupBenchmarks]. */
  List<Benchmark> _benchmarks;

  /** Buffer results here before dumping out on the page. */
  StringBuffer _resultsWriter;

  BenchmarkRunner()
      : _resultsWriter = new StringBuffer(),
        _benchmarks = new List<Benchmark>(),
        _solveLoops = const [10, 30],
        _steps = const [10, 100, 500, 2000];

  /**
   * Adds the specified benchmarks to the benchmark suite. Modify this method
   * directly to determine which benchmarks are included and the order in which
   * they are run.
   */
  void setupBenchmarks(String filter) {
    final benchmarks = [
      new BallDropBench(_solveLoops, _steps),
      new BallCageBench(_solveLoops, _steps),
      new CircleStressBench(_solveLoops, _steps),
      new DominoPlatformBench(_solveLoops, _steps),
      new DominoTowerBench(_solveLoops, _steps),
    ];

    if (filter == null || filter.isEmpty) {
      _benchmarks = benchmarks;
    } else {
      List<String> filterList = filter.split(",").map((e) => e.trim());
      benchmarks.forEach((benchmark) {
          if (filterList.indexOf(benchmark.name) != -1)
            _benchmarks.add(benchmark);
      });
    }
  }

  /**
   * Runs and records the results of each benchmark included in [setupBenchmarks].
   */
  void runBenchmarks() {
    for (Benchmark benchmark in _benchmarks) {
      print('Running ${benchmark.name}');
      _resultsWriter.clear();
      benchmark.runBenchmark(_resultsWriter);
      print("$_resultsWriter------------------------------------------------");
    }
  }

  /**
   * Initializes the given benchmark and adds to the end of the queue of
   * benchmarks to run.
   */
}

void main() {
  // TODO(dominich): Options for step sizes.
  final runner = new BenchmarkRunner();

  var parser = new ArgParser();
  parser.addOption('filter', abbr: 'f');
  var results = parser.parse(new Options().arguments);
  runner.setupBenchmarks(results['filter']);
  runner.runBenchmarks();
}
